#include <avr/io.h>
#include <util/delay.h>
#include "i2c.h"
#include "lcd.h"

#define MCP79410_RTC_WRITE_ADDRESS 0xDE
#define MCP79410_RTC_READ_ADDRESS 0xDF
#define MCP79410_EEPROM_WRITE_ADDRESS 0xAE
#define MCP79410_EEPROM_READ_ADDRESS 0xAF
#define MCP79410_RTCSEC 0x00

void rtcReadRegister(uint8_t reg, uint8_t * data);
void rtcWriteRegister(uint8_t reg, uint8_t data);

int main(void) {
	i2cInit();
	lcdInit();
	lcdInitPrintf();
	rtcWriteRegister(MCP79410_RTCSEC, 0b10000000);
	while(1){
		uint8_t rtcsec;
		rtcReadRegister(MCP79410_RTCSEC, &rtcsec);
		uint8_t secondsTens = (rtcsec & 0b01110000) >> 4;
		uint8_t secondsOnes = (rtcsec & 0b00001111);
		lcdGotoXY(0, 0);
		printf("%d%d", secondsTens, secondsOnes);
	}
}

void rtcReadRegister(uint8_t reg, uint8_t * data) {
	i2cStart();
	i2cSendAddress(MCP79410_RTC_WRITE_ADDRESS);
	i2cSendData(reg);
	i2cStart();
	i2cSendAddress(MCP79410_RTC_READ_ADDRESS);
	i2cReceive(1, data);
	i2cStop();
}

void rtcWriteRegister(uint8_t reg, uint8_t data) {
	i2cStart();
	i2cSendAddress(MCP79410_RTC_WRITE_ADDRESS);
	i2cSendData(reg);
	i2cSendData(data);
	i2cStop();
}

void rtcReadRegisters(uint8_t reg, uint8_t * data, uint8_t size) {
	i2cStart();
	i2cSendAddress(MCP79410_RTC_WRITE_ADDRESS);
	i2cSendData(reg);
	i2cStart();
	i2cSendAddress(MCP79410_RTC_READ_ADDRESS);
	for (uint8_t i = 0; i < size; i++) {
		i2cReceive(i == size - 1, data++);
	}
	i2cStop();
}

void rtcWriteRegisters(uint8_t reg, uint8_t * data, uint8_t size) {
	i2cStart();
	i2cSendAddress(MCP79410_RTC_WRITE_ADDRESS);
	i2cSendData(reg);
	for (uint8_t i = 0; i < size; i++) {
		i2cSendData(data[i]);
	}
	i2cStop();
}